# portfolio website
<a href="http://www.djangoproject.com/"><img src="https://www.djangoproject.com/m/img/badges/djangoproject120x25.gif" border="0" alt="A Django project." title="A Django project." /></a> [![CircleCI](https://circleci.com/gh/Muchogoc/portfolio/tree/master.svg?style=svg)](https://circleci.com/gh/Muchogoc/portfolio/tree/master)

Simple project for learning django and devops for backend development
